/*
 * Copyright 2009 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.isam.cache;

import dk.vajhoej.isam.Key;

/**
 * Interface IsamCache represents a cache to be used by CacheIsamSource.
 */
public interface IsamCache {
	/**
	 * Get object from cache.
	 * @param t type
	 * @param k key
	 * @return object
	 */
	public <T,TK> T get(Class<T> t, Key<TK> k);
	/**
	 * Put object in cache.
	 * @param k key
     * @param o object
	 */
	public <T,TK> void put(Key<TK> k, T o);
	/**
	 * Remove object from cache.
     * @param clz type
	 * @param k key
	 */
	public <T,TK> void remove(Class<T> clz, Key<TK> k);
	/**
	 * Get hit rate.
	 * @return cache hit rate
	 */
	public double getHitRate();
}
