/*
 * Copyright 2009 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.isam.dummy;

import java.util.logging.Logger;

import dk.vajhoej.isam.IsamException;
import dk.vajhoej.isam.IsamResult;
import dk.vajhoej.isam.IsamSource;
import dk.vajhoej.isam.Key;
import dk.vajhoej.record.RecordException;

/**
 * Class DummyIsamSource is a "do nothing" implementation of ISAM source.
 * All writes succeed. All reads return nothing.
 * It is only intended for testing purposes.
 */
public class DummyIsamSource implements IsamSource {
    private static Logger log = Logger.getLogger(DummyIsamSource.class.getName()); 
    public <T, TK> T read(Class<T> t, Key<TK> k) throws IsamException, RecordException {
        log.warning("DummyIsamSource read called");
        return null;
    }
    public <T> void create(T o) throws IsamException, RecordException {
        log.warning("DummyIsamSource create called");
    }
    public <T> void update(T o) throws IsamException, RecordException {
        log.warning("DummyIsamSource update called");
    }
    public <T, TK> void delete(Class<T> t, Key<TK> k) throws IsamException, RecordException {
        log.warning("DummyIsamSource delete called");
    }
    public void close() throws IsamException {
        log.warning("DummyIsamSource close called");
    }
    public <T, TK> IsamResult<T> readGE(Class<T> t, Key<TK> k) throws IsamException, RecordException {
        log.warning("DummyIsamSource readGE called");
        return new DummyIsamResult<T>();
    }
    public <T, TK> IsamResult<T> readGT(Class<T> t, Key<TK> k) throws IsamException, RecordException {
        log.warning("DummyIsamSource readGT called");
        return new DummyIsamResult<T>();
    }
    public <T, TK> IsamResult<T> readLE(Class<T> t, Key<TK> k) throws IsamException, RecordException {
        log.warning("DummyIsamSource readLE called");
        return new DummyIsamResult<T>();
    }
    public <T, TK> IsamResult<T> readLT(Class<T> t, Key<TK> k) throws IsamException, RecordException {
        log.warning("DummyIsamSource readLT called");
        return new DummyIsamResult<T>();
    }
}
