/*
 * Copyright 2009 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.isam.emulated;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.logging.Level;
import java.util.logging.Logger;

import dk.vajhoej.isam.IsamException;
import dk.vajhoej.isam.IsamResult;
import dk.vajhoej.record.RecordException;
import dk.vajhoej.record.StructReader;

/**
 * Class EmulatedIsamResult is a result from a find operation in an emulated ISAM source.
 */
public class EmulatedIsamResult<T> implements IsamResult<T> {
    private static Logger log = Logger.getLogger(EmulatedIsamResult.class.getName());
	private Class<T> t;
	private Connection con;
	private PreparedStatement pstmt;
	private ResultSet rs;
	/**
	 * Create instance of EmulatedIsamResult.
	 * @param t type to load
	 * @param pstmt JDBC prepared statement
	 * @param rs JDBC result set
	 */
	public EmulatedIsamResult(Class<T> t, Connection con, PreparedStatement pstmt, ResultSet rs) {
		this.t = t;
		this.con = con;
		this.pstmt = pstmt;
		this.rs = rs;
	}
	public boolean read() throws IsamException {
		try {
		    boolean fnd = rs.next();
		    if(fnd) {
		        log.fine("More");
		    } else {
		        log.fine("No more");
		    }
			return fnd;
		} catch (SQLException e) {
			throw new IsamException("Database problem", e);
		}
	}
	public T current() throws IsamException, RecordException {
		try {
		    byte[] res = rs.getBytes(1);
		    log.finest("Length: " + res.length);
            if(log.isLoggable(Level.FINEST)) {
                log.finest("Bytes:" + LogHelper.byteArrayToString(res));
            }
			StructReader sr = new StructReader(res);
			return sr.read(t);
		} catch (SQLException e) {
			throw new IsamException("Database problem", e);
		}
	}
	public void close() throws IsamException {
		try {
			rs.close();
			pstmt.close();
			con.close();
		} catch (SQLException e) {
			throw new IsamException("Database problem", e);
		}
	}
}
