/*
 * Copyright 2009 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.isam.remote;

import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.logging.Logger;

import dk.vajhoej.isam.IsamException;
import dk.vajhoej.isam.IsamSource;
import dk.vajhoej.isam.cache.CacheIsamSource;

/**
 * Class SourceThread is the server side of a single remote ISAM source.
 */
public class SourceThread extends Thread {
    private static Logger log = Logger.getLogger(SourceThread.class.getName());
	private IsamSource isam;
	private ServerSocket srv;
	/**
	 * Create instance of SourceThread.
	 * @param isam ISAM source
	 * @param port port number to be used by clients
	 * @param cache cache data
	 * @throws IsamException if problems with either ISAM source or socket
	 */
	public SourceThread(IsamSource isam, int port, boolean cache) throws IsamException {
		try {
			if(cache) {
				this.isam = new CacheIsamSource(isam);
			} else {
				this.isam = isam;
			}
			this.srv = new ServerSocket(port);
		} catch (IOException e) {
			throw new IsamException("Initialization problem", e);
		}
	}
	@Override
	public void run() {
		try {
			for(;;) {
				Socket cli = srv.accept();
				log.fine("Accepted connection from " + cli.getInetAddress().getHostName() + " and starting client thread");
				Thread t = new ClientThread(cli, isam);
				t.start();
			}
		} catch (IOException e) {
			e.printStackTrace(System.err);
		}
	}
}
